=========
Changelog
=========

Version 0.6
===========

* Curated the list of packages in ``environment.yml``
* Editable install of package direclty in ``environment.yml``

Version 0.5.1
=============

- Fix ``isort`` when namespaces are used
- Fix wrongs docs, i.e. rst -> md

Version 0.5
===========

- Updated to use PyScaffold v4 API
- Updated Cirrus CI config file
- Added new useful tasks to ``tox.ini``
- Renamed ``environment.yaml`` to ``environment.yml``
- Added `Yellowbrick <https://www.scikit-yb.org/>`_ to ``environment.yml``

Version 0.4.1
=============

- Fix problem with additional new lines in Windows

Version 0.4
===========

- Add a `.gitignore` also in the `data` folder
- Changed wording in `README.md`

Version 0.3.1
=============

- Fixed wrong folder name in README.md template

Version 0.3
===========

- Added a configs folder

Version 0.2.1
=============

- Fixed some docs
- Adjusted line lengths
- Some cosmetic changes

Version 0.2
===========

- Reworked the general layout some more

Version 0.1
===========

- Initial commit
